==> huaweicloudsdkdws-3.1.99-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/create_logical_cluster_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateLogicalClusterRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'logical_cluster': 'CreateLogicalClusterInfo'
    }

    attribute_map = {
        'logical_cluster': 'logical_cluster'
    }

    def __init__(self, logical_cluster=None):
        """CreateLogicalClusterRequestBody

        The model defined in huaweicloud sdk

        :param logical_cluster: 
        :type logical_cluster: :class:`huaweicloudsdkdws.v2.CreateLogicalClusterInfo`
        """
        
        

        self._logical_cluster = None
        self.discriminator = None

        self.logical_cluster = logical_cluster

    @property
    def logical_cluster(self):
        """Gets the logical_cluster of this CreateLogicalClusterRequestBody.

        :return: The logical_cluster of this CreateLogicalClusterRequestBody.
        :rtype: :class:`huaweicloudsdkdws.v2.CreateLogicalClusterInfo`
        """
        return self._logical_cluster

    @logical_cluster.setter
    def logical_cluster(self, logical_cluster):
        """Sets the logical_cluster of this CreateLogicalClusterRequestBody.

        :param logical_cluster: The logical_cluster of this CreateLogicalClusterRequestBody.
        :type logical_cluster: :class:`huaweicloudsdkdws.v2.CreateLogicalClusterInfo`
        """
        self._logical_cluster = logical_cluster

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateLogicalClusterRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.148-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/create_logical_cluster_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateLogicalClusterRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'logical_cluster': 'CreateLogicalClusterInfo'
    }

    attribute_map = {
        'logical_cluster': 'logical_cluster'
    }

    def __init__(self, logical_cluster=None):
        r"""CreateLogicalClusterRequestBody

        The model defined in huaweicloud sdk

        :param logical_cluster: 
        :type logical_cluster: :class:`huaweicloudsdkdws.v2.CreateLogicalClusterInfo`
        """
        
        

        self._logical_cluster = None
        self.discriminator = None

        self.logical_cluster = logical_cluster

    @property
    def logical_cluster(self):
        r"""Gets the logical_cluster of this CreateLogicalClusterRequestBody.

        :return: The logical_cluster of this CreateLogicalClusterRequestBody.
        :rtype: :class:`huaweicloudsdkdws.v2.CreateLogicalClusterInfo`
        """
        return self._logical_cluster

    @logical_cluster.setter
    def logical_cluster(self, logical_cluster):
        r"""Sets the logical_cluster of this CreateLogicalClusterRequestBody.

        :param logical_cluster: The logical_cluster of this CreateLogicalClusterRequestBody.
        :type logical_cluster: :class:`huaweicloudsdkdws.v2.CreateLogicalClusterInfo`
        """
        self._logical_cluster = logical_cluster

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateLogicalClusterRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
